set scheme s1color
set more off
cls


use oildata_replication.dta, clear



********************************
* DATA PREPARATION
********************************

rename country countrylong
encode countrylong, gen(country)

xtset country month
sort country month 


gen p = 100*q830wti/pculfer
gen dlp = (D.p / L.p) 
gen dlipafe = D.afe_ip / L.afe_ip
gen dlipeme = D.eme_ip / L.eme_ip
gen dlip = D.ip / L.ip
gen dlc = D.oil_cons_doe / L.oil_cons_doe
gen dly_doe 		= (D.oil_prod_doe / L.oil_prod_doe) 
gen lag1dlip = L.dlip
gen lag1dlipafe = L.dlipafe
gen lag1dlipeme = L.dlipeme

levelsof iso_code, c l(clist)

label var dlc	 		"Oil consumption, monthly % change"
label var dlp 			"Oil Price, monthly % change"
label var dly_doe 		"Oil Production, monthly % change"
label var dlip 			"Country-Specific IP, monthly % change"
label var dlipafe 		"Adv.Econ. IP, monthly % change"
label var dlipeme 		"Eme.Econ. IP, monthly % change"









**************************************************
* CREATE CANDIDATE SHOCKS
**************************************************
keep if tin(1984m12,2015m12)

gen d_oil_prod_w = 100*(D.oil_prod_doe/L.oil_prod_wld_doe) 

* SHOCK 1: All changes in oil production when 
* a country makes a contribution to world oil production less than -2 percent
gen dy_cand1 = d_oil_prod_w if (d_oil_prod_w<-0.02*100) 


* SHOCK 2: All changes in oil production when 
* a country makes a contribution to world oil production less than -0.66 percent
* AND own production relative to a 6-month moving averge drops more than 20% 
* AND more than 5 standard deviations.
egen sd_dy_doe = sd(dly_doe) if tin(1985m1,2015m12), by(country)
tssmooth ma oil_prod_doe_ma = oil_prod_doe, window(6 1 0) 
gen dy_smooth = (D.oil_prod_doe / L.oil_prod_doe_ma)
sort country month 
egen std_dy_smooth = sd(dy_smooth), by(country)

replace std_dy_smooth = . if tin(1985m1,2015m12)==0

#delimit ;
gen dy_cand2 = d_oil_prod_w if 
(d_oil_prod_w<-0.0066*100 & dly_doe<=-0.195 & dly_doe<=-3.95*sd_dy_doe) | 
(d_oil_prod_w<-0.01*100 & dly_doe<-0.5) |
(dy_smooth<-5*std_dy_smooth)  ;
#delimit cr
replace dy_cand2 = . if dy_smooth==.


// Drop unused observations to keep dataset clean
drop if oil_prod_doe==. & oil_cons==.




*********************************************
* CREATE INSTRUMENT
*********************************************
keep if tin(1985m1,2015m12)
xi i.country

gen shock2 = .

replace shock2 = d_oil_prod_w  if tin(1985m1,1985m1) & countrylong=="Iran" 

replace shock2 = d_oil_prod_w  if tin(1986m4,1986m4) & countrylong=="Norway" 
replace shock2 = d_oil_prod_w if tin(1987m3,1987m3) & countrylong=="Ecuador"
replace shock2 = d_oil_prod_w if tin(1987m9,1987m9) & countrylong=="Iran"
replace shock2 = d_oil_prod_w if tin(1990m8,1990m8) & (countrylong=="Iraq" | countrylong=="Kuwait" | countrylong=="United Arab Emirates")

replace shock2 = d_oil_prod_w if tin(1995m10,1995m10) & countrylong=="Mexico"
replace shock2 = d_oil_prod_w if tin(1997m6,1997m6) & countrylong=="Iraq"
replace shock2 = d_oil_prod_w if tin(2000m12,2000m12) & countrylong=="Iraq"
replace shock2 = d_oil_prod_w if tin(2001m6,2001m6) & countrylong=="Iraq"
replace shock2 = d_oil_prod_w if tin(2002m4,2002m4) & countrylong=="Iraq"

replace shock2 = d_oil_prod_w if tin(2002m12,2002m12) & countrylong=="Venezuela"
replace shock2 = d_oil_prod_w if tin(2003m4,2003m4) & countrylong=="Iraq"
replace shock2 = d_oil_prod_w if tin(2005m9,2005m9) & countrylong=="United States"
replace shock2 = d_oil_prod_w if tin(2008m9,2008m9) & countrylong=="United States"
replace shock2 = d_oil_prod_w if tin(2011m3,2011m3) & countrylong=="Libya"

egen instrumento2 = total(shock2), by(month)
replace instrumento2 = . if instrumento2==0  
replace instrumento2 = . if shock2!=.  

label var instrumento2 	"Exogenous Oil Shock by Period"




****************************
* REPRODUCE KEY RESULTS
****************************

// REPLICATION OF FIRST STAGE REGRESSION (EQUATION 15)
regress dlp instrumento2 if dly_doe!=. & countrylong=="Canada"
gen f2 = e(F)


// REPLICATION OF SUPPLY EQUATION (#16)
ivreg2 dly_doe  _I* (dlp =  instrumento2), partial(_I*) cl(country month) small 


// REPLICATION OF DEMAND EQUATION (#17)
ivreg2 dlc dlip dlipafe dlipeme lag1dlip lag1dlipafe lag1dlipeme _I* (dlp =  instrumento2), partial(_I* dlip dlipafe dlipeme lag1dlip lag1dlipafe lag1dlipeme) cl(country month) small 





/* FOR EXPORTING ONLY, UNCOMMENT LINES BELOW
keep if tin(1984m11,2015m12)
keep if countrylong=="Canada"
replace instrumento2 = 0 if instrumento2==.
export delimited month instrumento2 using cci_shocks_monthly.csv, replace




